#
# spec file for package grype-db
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           grype-db
Version:        0.27.4
Release:        1.1
Summary:        A vulnerability scanner for container images and filesystems
License:        Apache-2.0
URL:            https://github.com/anchore/grype-db
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23
BuildRequires:  zsh

%description
Application to create a Grype vulnerability database from upstream
vulnerability data sources.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/anchore/grype-db/cmd/grype-db/application.version=v%{version} \
   -X github.com/anchore/grype-db/cmd/grype-db/application.gitCommit=${COMMIT_HASH} \
   -X github.com/anchore/grype-db/cmd/grype-db/application.gitDescription=v%{version} \
   -X github.com/anchore/grype-db/cmd/grype-db/application.buildDate=$BUILD_DATE" \
   -o bin/%{name} ./cmd/%{name}/

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Sat Dec 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.27.4:
  * chore(deps): update anchore dependencies (#455)
  * chore(deps): Bump actions/checkout from 4.2.1 to 4.2.2 (#453)
  * chore(deps): Bump actions/setup-go from 5.1.0 to 5.2.0 (#454)
  * add update anchore dependencies workflow (#452)
* Wed Dec 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.27.3:
  * chore(deps): update anchore dependencies (#451)
  * chore(deps): Bump golang.org/x/sync from 0.9.0 to 0.10.0 (#448)
  * chore(deps): Bump actions/cache from 4.1.2 to 4.2.0 (#450)
  * Enable packaging v6 DBs (#437)
  * Add transformers for v6 DB schema (#436)
  * fix: use timestamp from only provider if only one provider
    (#445)
  * add request retry count for nvd (#444)
  * chore(deps): Bump github.com/Masterminds/semver/v3 from 3.3.0
    to 3.3.1 (#430)
  * chore(deps): Bump github.com/stretchr/testify from 1.9.0 to
    1.10.0 (#439)
  * Update grype-db bootstrap tools to latest versions. (#442)
  * add more retrys for NVD provider (#443)
* Tue Nov 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.27.2:
  * ignore NVD data age + tests (#441)
  * ignore NVD data age (#440)
  * remove v1 & v2 processors (#438)
* Fri Nov 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.27.1:
  * Update Grype to v0.85.0 (#435)
  * remove push event for code gen
  * Remove support for v1 & v2 schemas (#434)
  * add os codename fetcher/helper method (#433)
  * Migrate common processor code to internal (#432)
  * chore(deps): Bump golang.org/x/text from 0.19.0 to 0.20.0
    (#426)
  * chore(deps-dev): Bump werkzeug from 3.0.3 to 3.0.6 (#427)
  * Update grype-db bootstrap tools to latest versions. (#428)
  * chore(deps): Bump github.com/anchore/grype from 0.83.0 to
    0.84.0 (#424)
* Tue Oct 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.27.0:
  * chore(deps): Bump github.com/anchore/grype from 0.82.2 to
    0.83.0 (#420)
  * chore(deps): Bump actions/checkout from 4.2.1 to 4.2.2 (#416)
  * chore(deps): Bump actions/setup-go from 5.0.2 to 5.1.0 (#417)
* Thu Oct 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package grype-db: create a Grype vulnerability database from
  upstream vulnerability data sources
